LQMToolset
==========
[![Documentation Status](https://readthedocs.org/projects/lqmtoolset/badge/?version=latest)](https://readthedocs.org/projects/lqmtoolset/?badge=latest)
[![PyPI version](https://badge.fury.io/py/lqmt.svg)](https://badge.fury.io/py/lqmt)
[![Build Status](https://travis-ci.org/anl-cyberscience/LQMToolset.svg?branch=master)](https://travis-ci.org/anl-cyberscience/LQMToolset)

The Last Quarter Mile Toolset is flexible framework that allows automation to process cyber threat information (CTI) and update endpoint defense tools.

### Install
`Python3` and [pip](https://pypi.python.org/pypi/pip) are required for easy installation. If those requirements are met, then input the following command in the terminal:
```
pip3 install lqmt
```
For more detailed installation instructions and for handling certain edge cases, see [the installation documentation](https://lqmtoolset.readthedocs.org/en/latest/install/)

### Documentation
See [https://lqmtoolset.readthedocs.io/](https://lqmtoolset.readthedocs.io/).

### Contact
Any questions about the Last Quarter Mile Toolset can be directed to the CFM team at cfmteam@anl.gov. For general information about the CFM project, visit our website at http://www.anl.gov/cfm
